# Configurations

Initializing...

## Inputs

Vault path
Failed to load setting
i
Your Obsidian Vault folder.
Entrypoint
Failed to load setting
i
The note that is to become the homepage of your new site. In default mode, ObsidianHtml will start compiling your website starting with this note, and following any links to any other note. This note has to be in the vault selected above.

## Outputs

Markdown output folder
Failed to load setting
i
When ObsidianHtml converts your notes, it first compiles proper markdown notes. This setting determines where those files are exported to.
Markdown entrypoint path
Failed to load setting
i

By default this is `(markdown output folder)/index.md`.

This setting is analogous to the entrypoint setting for your notes, just for the markdown to html conversion, instead of the obsidian to markdown conversion.

You can ignore this setting at the moment.

## Wizard Settings

### Publish to Gitpage

Repo folder path
Failed to load setting
i
When using --publish this is the repo that the html will be written to.

## General Settings

Global config folder
Failed to load setting
i
This folder contains all the settings that you define here. When you run the gui it will use these settings.

If you run `obsidianhtml -i config.yml` the settings set in the gui are ignored.

To use the gui settings in the commandline run `obsidianhtml --publish`.